@@ -110,6 +110,7 @@ bool g_cl_progress = 0;
 bool g_cl_Progress = 0;
 bool g_cl_rinfo = 0;
 bool g_cl_no_color = 0;
+bool g_cl_beep = 0;
 int g_cl_verbose = 1;
 ArgParse::apfloatvec g_cl_cropWindow;
 ArgParse::apstring g_cl_rc_path = "";
@@ -124,6 +125,8 @@ ArgParse::apstring g_cl_type = "";
 ArgParse::apstring g_cl_addtype = "";
 ArgParse::apstring g_cl_mode = "rgba";
 ArgParse::apstring g_cl_strprogress = "Frame (%f) %p%% complete [ %s secs / %S left ]";
+ArgParse::apstring g_cl_framesList = "";
+ArgParse::apintvec g_cl_frames;
 
 #ifdef	AQSIS_SYSTEM_POSIX
 bool g_cl_syslog = 0;
@@ -342,7 +345,7 @@ int main( int argc, const char** argv )
 #elif AQSIS_SYSTEM_MACOSX
     CFURLRef pluginRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
     CFStringRef macPath = CFURLCopyFileSystemPath(pluginRef, kCFURLPOSIXPathStyle);
-    const char *pathPtr = "/User/pgregory/aqsis/renderer/build"; //CFStringGetCStringPtr(macPath, CFStringGetSystemEncoding());
+    const char *pathPtr = CFStringGetCStringPtr(macPath, CFStringGetSystemEncoding());
 
 	g_rc_path = pathPtr;
 	g_shader_path = pathPtr;
@@ -405,7 +408,10 @@ int main( int argc, const char** argv )
         ap.argString( "dsolibs", "=string\aOverride the default dso searchpath(s) [" + g_dso_path + "]", &g_cl_dso_path );
         ap.argString( "procedurals", "=string\aOverride the default procedural searchpath(s) [" + g_procedural_path + "]", &g_cl_procedural_path );
         ap.argString( "plugins", "=string\aOverride the default plugin searchpath(s) [" + g_plugin_path + "]", &g_cl_plugin_path );
+		ap.argInts( "frames", " f1 f2\aSpecify a starting/ending frame to render (inclusive).", &g_cl_frames, ArgParse::SEP_ARGV, 2);
+		ap.argString( "frameslist", "=string\aSpecify a range of frames to render, ',' separated with '-' to indicate ranges.", &g_cl_framesList);
         ap.argFlag( "nocolor", "\aDisable colored output", &g_cl_no_color );
+        ap.argFlag( "beep", "\aBeep on completion of all ribs", &g_cl_beep );
         ap.alias( "nocolor", "nc" );
 #ifdef	AQSIS_SYSTEM_POSIX
         ap.argFlag( "syslog", "\aLog messages to syslog", &g_cl_syslog );
@@ -435,8 +441,12 @@ int main( int argc, const char** argv )
 
         if ( g_cl_version )
         {
-            std::cout << "aqsis version " << VERSION_STR << std::endl;
-            std::cout << "compiled " << __DATE__ << " " << __TIME__ << std::endl;
+            std::cout << "aqsis version " << VERSION_STR
+#ifdef _DEBUG
+		      << " (debug build)"
+#endif
+		      << "\n"
+                      << "compiled " << __DATE__ << " " << __TIME__ << "\n";
             exit( 0 );
         }
 
@@ -535,6 +545,11 @@ int main( int argc, const char** argv )
 
     StopMemoryDebugging();
 
+	if(g_cl_beep)
+	{
+		std::cout << "\a" << std::ends;
+	}
+
     if(g_cl_pause)
     {
         std::cout << "Press any key..." << std::ends;
@@ -585,6 +600,17 @@ void RenderFile( FILE* file, std::string&  name )
 	fclose( rcfile );
     }
 
+	librib::ClearFrames();
+	// Pass in specified frame lists.
+	if(g_cl_frames.size() == 2)
+	{
+		std::stringstream strframes;
+		strframes << g_cl_frames[0] << "-" << g_cl_frames[1] << std::ends;
+		librib::AppendFrames(strframes.str().c_str());
+	}
+	if(!g_cl_framesList.empty())
+		librib::AppendFrames(g_cl_framesList.c_str());
+
     librib::Parse( file, name, *renderengine, std::cerr, NULL );
 
     RiEnd();
