@@ -167,7 +167,14 @@ CqRibBinaryDecoder::initZlib( int buffersize )
     zbuffersize = 2;
     for (len = 0; len < 2; len++)
     {
-        gc( c );
+        try
+		{
+			gc( c );
+		}
+		catch(std::string)
+		{
+			return;
+		}
         if (c != gz_magic[len])
         {
             if (len != 0) zavailable++, zcurrent--;
@@ -835,11 +842,15 @@ TqInt CqRibBinaryDecoder::read( TqPchar buffer, TqUint size )
         while ( cv.size() < size )
         {
             getNext();
-            if( cv.back() == '\n' )
+
+            if( !cv.empty() )
             {
-                size = cv.size() + 1;
-                break;
-            };
+                if( cv.back() == '\n' )
+                {
+                    size = cv.size() + 1;
+                    break;
+                }
+            }
         }
     }
     catch ( std::string & s )
