@@ -96,31 +96,31 @@ char*	gVariableNames[ EnvVars_Last ] =
     };
 TqUlong	gVariableTokens[ EnvVars_Last ] =
     {
-        CqParameter::hash( gVariableNames[ 0 ] ),
-        CqParameter::hash( gVariableNames[ 1 ] ),
-        CqParameter::hash( gVariableNames[ 2 ] ),
-        CqParameter::hash( gVariableNames[ 3 ] ),
-        CqParameter::hash( gVariableNames[ 4 ] ),
-        CqParameter::hash( gVariableNames[ 5 ] ),
-        CqParameter::hash( gVariableNames[ 6 ] ),
-        CqParameter::hash( gVariableNames[ 7 ] ),
-        CqParameter::hash( gVariableNames[ 8 ] ),
-        CqParameter::hash( gVariableNames[ 9 ] ),
-        CqParameter::hash( gVariableNames[ 10 ] ),
-        CqParameter::hash( gVariableNames[ 11 ] ),
-        CqParameter::hash( gVariableNames[ 12 ] ),
-        CqParameter::hash( gVariableNames[ 13 ] ),
-        CqParameter::hash( gVariableNames[ 14 ] ),
-        CqParameter::hash( gVariableNames[ 15 ] ),
-        CqParameter::hash( gVariableNames[ 16 ] ),
-        CqParameter::hash( gVariableNames[ 17 ] ),
-        CqParameter::hash( gVariableNames[ 18 ] ),
-        CqParameter::hash( gVariableNames[ 19 ] ),
-        CqParameter::hash( gVariableNames[ 20 ] ),
-        CqParameter::hash( gVariableNames[ 21 ] ),
-        CqParameter::hash( gVariableNames[ 22 ] ),
-        CqParameter::hash( gVariableNames[ 23 ] ),
-        CqParameter::hash( gVariableNames[ 24 ] ),
+        CqString::hash( gVariableNames[ 0 ] ),
+        CqString::hash( gVariableNames[ 1 ] ),
+        CqString::hash( gVariableNames[ 2 ] ),
+        CqString::hash( gVariableNames[ 3 ] ),
+        CqString::hash( gVariableNames[ 4 ] ),
+        CqString::hash( gVariableNames[ 5 ] ),
+        CqString::hash( gVariableNames[ 6 ] ),
+        CqString::hash( gVariableNames[ 7 ] ),
+        CqString::hash( gVariableNames[ 8 ] ),
+        CqString::hash( gVariableNames[ 9 ] ),
+        CqString::hash( gVariableNames[ 10 ] ),
+        CqString::hash( gVariableNames[ 11 ] ),
+        CqString::hash( gVariableNames[ 12 ] ),
+        CqString::hash( gVariableNames[ 13 ] ),
+        CqString::hash( gVariableNames[ 14 ] ),
+        CqString::hash( gVariableNames[ 15 ] ),
+        CqString::hash( gVariableNames[ 16 ] ),
+        CqString::hash( gVariableNames[ 17 ] ),
+        CqString::hash( gVariableNames[ 18 ] ),
+        CqString::hash( gVariableNames[ 19 ] ),
+        CqString::hash( gVariableNames[ 20 ] ),
+        CqString::hash( gVariableNames[ 21 ] ),
+        CqString::hash( gVariableNames[ 22 ] ),
+        CqString::hash( gVariableNames[ 23 ] ),
+        CqString::hash( gVariableNames[ 24 ] ),
     };
 
 
@@ -162,6 +162,7 @@ void CqShaderExecEnv::Initialise( const TqInt uGridRes, const TqInt vGridRes, Iq
 {
     m_uGridRes = uGridRes;
     m_vGridRes = vGridRes;
+
     m_GridSize = ( uGridRes + 1 ) * ( vGridRes + 1 );
     m_LocalIndex = 0;
 
@@ -187,8 +188,8 @@ void CqShaderExecEnv::Initialise( const TqInt uGridRes, const TqInt vGridRes, Iq
     m_IlluminanceCacheValid = TqFalse;
 
     // Initialise the state bitvectors
-    m_CurrentState.SetSize( ( uGridRes + 1 ) * ( vGridRes + 1 ) );
-    m_RunningState.SetSize( ( uGridRes + 1 ) * ( vGridRes + 1 ) );
+    m_CurrentState.SetSize( m_GridSize );
+    m_RunningState.SetSize( m_GridSize );
     m_RunningState.SetAll( TqTrue );
 
 
@@ -277,7 +278,7 @@ void CqShaderExecEnv::Initialise( const TqInt uGridRes, const TqInt vGridRes, Iq
 IqShaderData* CqShaderExecEnv::FindStandardVar( const char* pname )
 {
     TqInt tmp = m_LocalIndex;
-    TqUlong htoken = CqParameter::hash( pname );
+    TqUlong htoken = CqString::hash( pname );
 
     for ( ; m_LocalIndex < EnvVars_Last; m_LocalIndex++ )
     {
@@ -295,7 +296,7 @@ IqShaderData* CqShaderExecEnv::FindStandardVar( const char* pname )
 TqInt	CqShaderExecEnv::FindStandardVarIndex( const char* pname )
 {
     TqInt tmp = m_LocalIndex;
-    TqUlong htoken = CqParameter::hash( pname );
+    TqUlong htoken = CqString::hash( pname );
     for ( ; m_LocalIndex < EnvVars_Last; m_LocalIndex++ )
     {
         if ( gVariableTokens[ m_LocalIndex ] == htoken )
