@@ -29,6 +29,7 @@
 #include	"aqsis.h"
 #include	<boost/shared_ptr.hpp>
 
+#include	"ishaderdata.h"
 #include	"vector3d.h"
 #include	"matrix.h"
 #include	"sstring.h"
@@ -41,7 +42,6 @@ struct IqSurface;
 struct IqAttributes;
 struct IqTransform;
 struct IqShader;
-struct IqShaderData;
 
 /** \enum EqEnvVars
  * Identifiers for the standard environment variables.
@@ -107,8 +107,8 @@ enum EqEnvVars
 #define	STRINGARRAYVAL	IqShaderData*
 #define	MATRIXARRAYVAL	IqShaderData*
 
-#define	DEFPARAM		IqShaderData* Result, IqShader* pShader=0
-#define	DEFVOIDPARAM	IqShader* pShader=0
+#define	DEFPARAM		IqShaderData* Result,IqShader* pShader=0
+#define	DEFVOIDPARAM	        IqShader* pShader=0
 #define	DEFPARAMVAR		DEFPARAM, int cParams=0, IqShaderData** apParams=0
 #define	DEFVOIDPARAMVAR	DEFVOIDPARAM, int cParams=0, IqShaderData** apParams=0
 
@@ -125,7 +125,7 @@ struct IqShaderExecEnv
     virtual	~IqShaderExecEnv()
     {}
 
-    virtual	void	Initialise( const TqInt uGridRes, const TqInt vGridRes, IqAttributes* pAttr, IqTransform* pTrans, IqShader* pShader, TqInt Uses ) = 0;
+    virtual	void	Initialise( const TqInt uGridRes, const TqInt vGridRes, IqAttributes* pAttr, const boost::shared_ptr<IqTransform>& pTrans, IqShader* pShader, TqInt Uses ) = 0;
     /** Get grid size in u
      */
     virtual	TqInt	uGridRes() const = 0;
@@ -143,7 +143,14 @@ struct IqShaderExecEnv
     virtual	const IqAttributes*	pAttributes() const = 0;
     /** Get a pointer to the associated transform.
      */
-    virtual	const IqTransform*	pTransform() const = 0;
+    virtual	boost::shared_ptr<const IqTransform>	pTransform() const = 0;
+	/** Set the pointer to the currently being lit surface
+	 */
+	virtual void SetCurrentSurface(IqSurface* pEnv) = 0;
+
+	/** Get the pointer to the currently being lit surface
+	 */
+	virtual const IqSurface* GetCurrentSurface() const = 0;
     /** Update all cached lighting results.
      */
     virtual	void	ValidateIlluminanceCache( IqShaderData* pP, IqShaderData* pN, IqShader* pShader ) = 0;
@@ -544,7 +551,8 @@ R SO_DerivType( IqShaderData* Var, IqShaderData* den, TqInt i, IqShaderExecEnv*
             den->GetValue( u1, i + 1 );
             den->GetValue( u2, i );
 		}
-        Retu = ( val1 - val2 ) / ( u1 - u2 );
+		if( ( val1 != val2 ) && ( u1 != u2 ) )
+			Retu = ( val1 - val2 ) / ( u1 - u2 );
     }
     else
     {
@@ -555,7 +563,8 @@ R SO_DerivType( IqShaderData* Var, IqShaderData* den, TqInt i, IqShaderExecEnv*
             den->GetValue( u1, i );
             den->GetValue( u2, i - 1 );
 		}
-        Retu = ( val2 - val1 ) / ( u2 - u1 );
+		if( ( val1 != val2 ) && ( u1 != u2 ) )
+			Retu = ( val2 - val1 ) / ( u2 - u1 );
     }
 
     // Calculate deriviative in v
@@ -568,7 +577,8 @@ R SO_DerivType( IqShaderData* Var, IqShaderData* den, TqInt i, IqShaderExecEnv*
             den->GetValue( v1, i + uRes + 1 );
             den->GetValue( v2, i );
 		}
-        Retv = ( val1 - val2 ) / ( v1 - v2 );
+		if( ( val1 != val2 ) && ( v1 != v2 ) )
+			Retv = ( val1 - val2 ) / ( v1 - v2 );
     }
     else
     {
@@ -579,7 +589,8 @@ R SO_DerivType( IqShaderData* Var, IqShaderData* den, TqInt i, IqShaderExecEnv*
             den->GetValue( v1, i );
             den->GetValue( v2, i - ( uRes - 1 ) );
 		}
-        Retv = ( val2 - val1 ) / ( v2 - v1 );
+		if( ( val1 != val2 ) && ( v1 != v2 ) )
+			Retv = ( val2 - val1 ) / ( v2 - v1 );
     }
 
     return ( Retu + Retv );
