@@ -264,6 +264,8 @@ void CqMicroPolyGrid::Shade()
 
     TqInt lUses = pSurface() ->Uses();
     TqInt gs = GridSize();
+    TqInt uRes = uGridRes();
+    TqInt vRes = vGridRes();
     TqInt gsmin1 = gs - 1;
     long cCulled = 0;
 
@@ -288,12 +290,19 @@ void CqMicroPolyGrid::Shade()
 
     // Setup uniform variables.
     if ( USES( lUses, EnvVars_E ) ) pVar(EnvVars_E) ->SetVector( vecE );
+
+    // Setup varying variables.
+    TqBool bdpu, bdpv;
+    bdpu = ( USES( lUses, EnvVars_dPdu ) );
+    bdpv = ( USES( lUses, EnvVars_dPdv ) );
+    IqShaderData * pSDP = pVar(EnvVars_P);
+    TqInt proj = QGetRenderContext()->GetIntegerOption( "System", "Projection" ) [ 0 ];
+
+    for ( i = gsmin1; i >= 0; i-- )
+    {
     if ( USES( lUses, EnvVars_du ) )
     {
-        for ( i = gsmin1; i >= 0; i-- )
-        {
             TqFloat v1, v2;
-            TqInt uRes = uGridRes();
             TqInt GridX = i % ( uRes + 1 );
 
             if ( GridX < uRes )
@@ -309,14 +318,9 @@ void CqMicroPolyGrid::Shade()
                 pVar(EnvVars_du) ->SetFloat( v1 - v2, i );
             }
         }
-    }
     if ( USES( lUses, EnvVars_dv ) )
     {
-        for ( i = gsmin1; i >= 0; i-- )
-        {
             TqFloat v1, v2;
-            TqInt uRes = uGridRes();
-            TqInt vRes = vGridRes();
             TqInt GridY = ( i / ( uRes + 1 ) );
 
             if ( GridY < vRes )
@@ -332,20 +336,17 @@ void CqMicroPolyGrid::Shade()
                 pVar(EnvVars_dv) ->SetFloat( v1 - v2, i );
             }
         }
-    }
-
-    if ( USES( lUses, EnvVars_Ci ) ) pVar(EnvVars_Ci) ->SetColor( gColBlack );
-    if ( USES( lUses, EnvVars_Oi ) ) pVar(EnvVars_Oi) ->SetColor( gColWhite );
-
-    // Setup varying variables.
-    TqBool bdpu, bdpv;
-    bdpu = ( USES( lUses, EnvVars_dPdu ) );
-    bdpv = ( USES( lUses, EnvVars_dPdv ) );
-    IqShaderData * pSDP = pVar(EnvVars_P);
-
-    for ( i = gsmin1; i >= 0; i-- )
-    {
-        pI->SetVector( pP[ i ], i );
+		switch ( proj )
+		{
+		    case	ProjectionOrthographic:
+				pI->SetVector( CqVector3D(0,0,1), i );
+				break;
+		    
+			case	ProjectionPerspective:
+			default:
+				pI->SetVector( pP[ i ], i );
+				break;
+		}
 
         if ( bdpu )
         {
@@ -356,7 +357,12 @@ void CqMicroPolyGrid::Shade()
             pVar(EnvVars_dPdv) ->SetVector( SO_DvType<CqVector3D>( pSDP, i, m_pShaderExecEnv.get(), Defvec ), i );
         }
     }
+    
+    if ( USES( lUses, EnvVars_Ci ) ) pVar(EnvVars_Ci) ->SetColor( gColBlack );
+    if ( USES( lUses, EnvVars_Oi ) ) pVar(EnvVars_Oi) ->SetColor( gColWhite );
+
     // Now try and cull any transparent MPs
+    cCulled = 0;
     if ( USES( lUses, EnvVars_Os ) && QGetRenderContext() ->optCurrent().GetIntegerOption( "System", "DisplayMode" ) [ 0 ] & ModeZ )
     {
         theStats.OcclusionCullTimer().Start();
@@ -417,9 +423,9 @@ void CqMicroPolyGrid::Shade()
     }
 
     // Now try and cull any hidden MPs if Sides==1
+    cCulled = 0;
     if ( ( pAttributes() ->GetIntegerAttribute( "System", "Sides" ) [ 0 ] == 1 ) && !m_pCSGNode )
     {
-        cCulled = 0;
         theStats.OcclusionCullTimer().Start();
         for ( i = gsmin1; i >= 0; i-- )
         {
@@ -593,6 +599,9 @@ void CqMicroPolyGrid::Split( CqImageBuffer* pImage, long xmin, long xmax, long y
     if ( NULL == pVar(EnvVars_P) )
         return ;
 
+    TqInt cu = uGridRes();
+    TqInt cv = vGridRes();
+
 	QGetRenderContext() ->Stats().MakeProject().Start();
     CqMatrix matCameraToRaster = QGetRenderContext() ->matSpaceToSpace( "camera", "raster", CqMatrix(), CqMatrix(), QGetRenderContext()->Time() );
     CqMatrix matCameraToObject0 = QGetRenderContext() ->matSpaceToSpace( "camera", "object", CqMatrix(), pSurface() ->pTransform() ->matObjectToWorld( pSurface() ->pTransform() ->Time( 0 ) ), QGetRenderContext()->Time() );
@@ -633,8 +642,8 @@ void CqMicroPolyGrid::Split( CqImageBuffer* pImage, long xmin, long xmax, long y
 		SqTriangleSplitLine sl;
 		CqVector3D v0, v1, v2;
 		v0 = aaPtimes[ iTime ][ 0 ];
-		v1 = aaPtimes[ iTime ][ uGridRes() ];
-		v2 = aaPtimes[ iTime ][ vGridRes() * ( uGridRes() + 1 ) ];
+		v1 = aaPtimes[ iTime ][ cu ];
+		v2 = aaPtimes[ iTime ][ cv * ( cu + 1 ) ];
 		// Check for clockwise, swap if not.
 		if( ( ( v1.x() - v0.x() ) * ( v2.y() - v0.y() ) - ( v1.y() - v0.y() ) * ( v2.x() - v0.x() ) ) >= 0 )
 		{
@@ -662,8 +671,8 @@ void CqMicroPolyGrid::Split( CqImageBuffer* pImage, long xmin, long xmax, long y
 	SqTriangleSplitLine sl;
 	CqVector3D v0, v1, v2;
 	v0 = aaPtimes[ 0 ][ 0 ];
-	v1 = aaPtimes[ 0 ][ uGridRes() ];
-	v2 = aaPtimes[ 0 ][ vGridRes() * ( uGridRes() + 1 ) ];
+	v1 = aaPtimes[ 0 ][ cu ];
+	v2 = aaPtimes[ 0 ][ cv * ( cu + 1 ) ];
 	// Check for clockwise, swap if not.
 	if( ( ( v1.x() - v0.x() ) * ( v2.y() - v0.y() ) - ( v1.y() - v0.y() ) * ( v2.x() - v0.x() ) ) >= 0 )
 	{
@@ -679,10 +688,6 @@ void CqMicroPolyGrid::Split( CqImageBuffer* pImage, long xmin, long xmax, long y
 
     QGetRenderContext() ->Stats().MakeProject().Stop();
 
-
-    TqInt cu = uGridRes();
-    TqInt cv = vGridRes();
-
     // Get the required trim curve sense, if specified, defaults to "inside".
     const CqString* pattrTrimSense = pAttributes() ->GetStringAttribute( "trimcurve", "sense" );
     CqString strTrimSense( "inside" );
@@ -901,8 +906,8 @@ void CqMotionMicroPolyGrid::Split( CqImageBuffer* pImage, long xmin, long xmax,
 		SqTriangleSplitLine sl;
 		CqVector3D v0, v1, v2;
 		v0 = aaPtimes[ iTime ][ 0 ];
-		v1 = aaPtimes[ iTime ][ pGridA->uGridRes() ];
-		v2 = aaPtimes[ iTime ][ pGridA->vGridRes() * ( pGridA->uGridRes() + 1 ) ];
+		v1 = aaPtimes[ iTime ][ cu ];
+		v2 = aaPtimes[ iTime ][ cv * ( cu + 1 ) ];
 		// Check for clockwise, swap if not.
 		if( ( ( v1.x() - v0.x() ) * ( v2.y() - v0.y() ) - ( v1.y() - v0.y() ) * ( v2.x() - v0.x() ) ) >= 0 )
 		{
@@ -1441,8 +1446,9 @@ void CqMicroPolygon::CalculateTotalBound()
 
 	// Calculate the boundary, and store the indexes in the cache.
 	const CqVector3D& B = pP[ m_Index + 1 ];
-	const CqVector3D& C = pP[ m_Index + m_pGrid->uGridRes() + 2 ];
-	const CqVector3D& D = pP[ m_Index + m_pGrid->uGridRes() + 1 ];
+	TqInt cu = m_pGrid->uGridRes();
+	const CqVector3D& C = pP[ m_Index + cu + 2 ];
+	const CqVector3D& D = pP[ m_Index + cu + 1 ];
 
 	TqShort BCMinX = 0;
 	TqShort BCMaxX = 0;
