@@ -404,8 +404,8 @@ TqBool	CqSurfacePatchBicubic::Diceable()
     if( NULL != poptGridSize )
         gs = poptGridSize[0];
 
-    if ( m_uDiceSize > gs) return TqFalse;
-    if ( m_vDiceSize > gs) return TqFalse;
+	if( m_uDiceSize * m_vDiceSize > gs * gs )
+		return TqFalse;
 
     return ( TqTrue );
 }
@@ -751,8 +751,9 @@ TqBool	CqSurfacePatchBilinear::Diceable()
     if( NULL != poptGridSize )
         gs = poptGridSize[0];
 
-    if ( m_uDiceSize > gs) return TqFalse;
-    if ( m_vDiceSize > gs) return TqFalse;
+	TqFloat gs2 = gs*gs;
+	if( m_uDiceSize > gs2 || m_vDiceSize > gs2 || (m_uDiceSize * m_vDiceSize) > gs2 )
+		return TqFalse;
 
     return ( TqTrue );
 }
