@@ -42,6 +42,7 @@ static TqBool IntersectLine( CqVector3D& P1, CqVector3D& T1, CqVector3D& P2, CqV
 static void ProjectToLine( const CqVector3D& S, const CqVector3D& Trj, const CqVector3D& pnt, CqVector3D& p );
 
 #define TOOLARGEQUADS 10000
+static TqUlong RIH_P = CqString::hash("P");
 
 CqQuadric::CqQuadric()
 {
@@ -226,8 +227,8 @@ void CqQuadric::NaturalDice( CqParameter* pParameter, TqInt uDiceSize, TqInt vDi
 {
     // Special case for "P", else normal bilinear dice for all others.
 
-    TqLong hash = CqParameter::hash(pData->strName().c_str());
-    if ( hash == CqParameter::hash("P") )
+    TqUlong hash = CqString::hash(pData->strName().c_str());
+    if ( hash == RIH_P )
     {
         CqVector3D	P;
         int v, u;
@@ -364,16 +365,16 @@ TqUlong CqQuadric::EstimateGridSize()
 
 CqSphere::CqSphere( TqFloat radius, TqFloat zmin, TqFloat zmax, TqFloat thetamin, TqFloat thetamax ) :
         m_Radius( radius ),
-        m_ZMin( zmin ),
-        m_ZMax( zmax ),
         m_ThetaMin( thetamin ),
         m_ThetaMax( thetamax )
 {
-    // Sanity check the values.
-    if( m_ZMin < -m_Radius )	m_ZMin = -m_Radius;
-    if( m_ZMin >  m_Radius )	m_ZMin =  m_Radius;
-    if( m_ZMax < -m_Radius )	m_ZMax = -m_Radius;
-    if( m_ZMax >  m_Radius )	m_ZMax =  m_Radius;
+    // Sanity check the values, while ensuring we keep the same signs.
+	TqFloat frad = fabs(m_Radius);
+    if( fabs(zmin) > frad )	zmin = frad*(zmin<0)?-1:1;
+    if( fabs(zmin) > frad )	zmin = frad*(zmin<0)?-1:1;
+
+    m_PhiMin = asin( zmin / m_Radius );
+    m_PhiMax = asin( zmax / m_Radius );
 }
 
 
@@ -385,8 +386,8 @@ CqSphere&	CqSphere::operator=( const CqSphere& From )
 {
     CqQuadric::operator=( From );
     m_Radius = From.m_Radius;
-    m_ZMin = From.m_ZMin;
-    m_ZMax = From.m_ZMax;
+    m_PhiMin = From.m_PhiMin;
+    m_PhiMax = From.m_PhiMax;
     m_ThetaMin = From.m_ThetaMin;
     m_ThetaMax = From.m_ThetaMax;
 
@@ -399,12 +400,9 @@ CqSphere&	CqSphere::operator=( const CqSphere& From )
 
 CqBound	CqSphere::Bound() const
 {
-    TqFloat phimin = ( m_ZMin > -m_Radius ) ? asin( m_ZMin / m_Radius ) : -( RI_PIO2 );
-    TqFloat phimax = ( m_ZMax < m_Radius ) ? asin( m_ZMax / m_Radius ) : ( RI_PIO2 );
-
     std::vector<CqVector3D> curve;
     CqVector3D vA( 0, 0, 0 ), vB( 1, 0, 0 ), vC( 0, 0, 1 );
-    Circle( vA, vB, vC, m_Radius, phimin, phimax, curve );
+    Circle( vA, vB, vC, m_Radius, m_PhiMin, m_PhiMax, curve );
 
     CqMatrix matRot( RAD ( m_ThetaMin ), vC );
     for ( std::vector<CqVector3D>::iterator i = curve.begin(); i != curve.end(); i++ )
@@ -423,7 +421,7 @@ CqBound	CqSphere::Bound() const
 
 TqInt CqSphere::PreSubdivide( std::vector<boost::shared_ptr<CqBasicSurface> >& aSplits, TqBool u )
 {
-    TqFloat zcent = ( m_ZMin + m_ZMax ) * 0.5;
+    TqFloat phicent = ( m_PhiMin + m_PhiMax ) * 0.5;
     TqFloat arccent = ( m_ThetaMin + m_ThetaMax ) * 0.5;
 
     boost::shared_ptr<CqSphere> pNew1( new CqSphere( *this ) );
@@ -436,8 +434,8 @@ TqInt CqSphere::PreSubdivide( std::vector<boost::shared_ptr<CqBasicSurface> >& a
     }
     else
     {
-        pNew1->m_ZMax = zcent;
-        pNew2->m_ZMin = zcent;
+        pNew1->m_PhiMax = phicent;
+        pNew2->m_PhiMin = phicent;
     }
 
     aSplits.push_back( pNew1 );
@@ -456,9 +454,7 @@ TqInt CqSphere::PreSubdivide( std::vector<boost::shared_ptr<CqBasicSurface> >& a
 
 CqVector3D CqSphere::DicePoint( TqInt u, TqInt v )
 {
-    TqFloat phimin = ( m_ZMin > -m_Radius ) ? asin( m_ZMin / m_Radius ) : RAD( -90.0 );
-    TqFloat phimax = ( m_ZMax < m_Radius ) ? asin( m_ZMax / m_Radius ) : RAD( 90.0 );
-    TqFloat phi = phimin + ( ( TqFloat ) v * ( phimax - phimin ) ) / m_vDiceSize;
+    TqFloat phi = m_PhiMin + ( ( TqFloat ) v * ( m_PhiMax - m_PhiMin ) ) / m_vDiceSize;
 
     TqFloat cosphi = cos( phi );
     TqFloat theta = RAD( m_ThetaMin + ( ( TqFloat ) u * ( m_ThetaMax - m_ThetaMin ) ) / m_uDiceSize );
