@@ -699,12 +699,12 @@ void	CqSurface::Transform( const CqMatrix& matTx, const CqMatrix& matITTx, const
  */
 CqParameter* CqSurface::FindUserParam( const char* name ) const
 {
-    CqString strName( name );
+TqUlong strName = CqString::hash(name );
     std::vector<CqParameter*>::const_iterator iUP;
     std::vector<CqParameter*>::const_iterator end = m_aUserParams.end();
     for ( iUP = m_aUserParams.begin(); iUP != end ; iUP++ )
     {
-        if( ( *iUP )->strName() == strName )
+        if( ( *iUP )->hash() == strName )
             return( *iUP );
     }
     return( NULL );
