@@ -48,6 +48,8 @@
 
 START_NAMESPACE( Aqsis )
 
+
+
 //----------------------------------------------------------------------
 /** \class CqBasicSurface
  * Abstract base surface class, which provides interfaces to geometry.  
@@ -498,53 +500,59 @@ public:
      */
     virtual void AddPrimitiveVariable( CqParameter* pParam )
     {
+    static TqUlong RIH_P = CqString::hash("P");
+    static TqUlong RIH_N = CqString::hash("N");
+    static TqUlong RIH_CS = CqString::hash("Cs");
+    static TqUlong RIH_OS = CqString::hash("Os");
+    static TqUlong RIH_S = CqString::hash("s");
+    static TqUlong RIH_T = CqString::hash("t") ;
+    static TqUlong RIH_U = CqString::hash("u");
+    static TqUlong RIH_V = CqString::hash("v");
+
         m_aUserParams.push_back( pParam );
 
-        if ( pParam->hash() == CqParameter::hash("P") )
+        if ( pParam->hash() == RIH_P )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_P ] );
             m_aiStdPrimitiveVars[ EnvVars_P ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("N") )
+        else if ( pParam->hash() == RIH_N )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_N ] );
             m_aiStdPrimitiveVars[ EnvVars_N ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("Cs") )
+
+        else if ( pParam->hash() == RIH_CS )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_Cs ] );
             m_aiStdPrimitiveVars[ EnvVars_Cs ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("Os") )
+        else if ( pParam->hash() == RIH_OS )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_Os ] );
             m_aiStdPrimitiveVars[ EnvVars_Os ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("s") )
+        else if ( pParam->hash() == RIH_S  )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_s ] );
             m_aiStdPrimitiveVars[ EnvVars_s ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("t") )
+        else if ( pParam->hash() == RIH_T)
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_t ] );
             m_aiStdPrimitiveVars[ EnvVars_t ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("u") )
+        else if ( pParam->hash() == RIH_U)
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_u ] );
             m_aiStdPrimitiveVars[ EnvVars_u ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("v") )
+        else if ( pParam->hash() == RIH_V )
         {
             assert( -1 == m_aiStdPrimitiveVars[ EnvVars_v ] );
             m_aiStdPrimitiveVars[ EnvVars_v ] = m_aUserParams.size() - 1;
         }
-        else if ( pParam->hash() == CqParameter::hash("N") )
-        {
-            assert( -1 == m_aiStdPrimitiveVars[ EnvVars_N ] );
-            m_aiStdPrimitiveVars[ EnvVars_N ] = m_aUserParams.size() - 1;
-        }
+        
     }
 
     /** Determine whether this surface can be trimmed
